==> iplass-core-3.2.7-sources.jar: org/iplass/mtp/impl/entity/cache/QueryCacheKey.java <==
/*
 * Copyright (C) 2023 INFORMATION SERVICES INTERNATIONAL - DENTSU, LTD. All Rights Reserved.
 * 
 * Unless you have purchased a commercial license,
 * the following license terms apply:
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.iplass.mtp.impl.entity.cache;

import org.iplass.mtp.entity.query.Query;

class QueryCacheKey {
	final boolean returnStructuredEntity;
	final Query query;
	private final int hash;
	
	public QueryCacheKey(Query query, boolean returnStructuredEntity) {
		this.query = query;
		this.returnStructuredEntity = returnStructuredEntity;
		hash = genHash();
	}

	private int genHash() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((query == null) ? 0 : query.hashCode());
		result = prime * result + (returnStructuredEntity ? 1231 : 1237);
		return result;
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		QueryCacheKey other = (QueryCacheKey) obj;
		if (returnStructuredEntity != other.returnStructuredEntity)
			return false;
		if (query == null) {
			if (other.query != null)
				return false;
		} else if (!query.equals(other.query))
			return false;
		return true;
	}
}

==> iplass-core-4.0.1-sources.jar: org/iplass/mtp/impl/entity/cache/QueryCacheKey.java <==
/*
 * Copyright (C) 2023 DENTSU SOKEN INC. All Rights Reserved.
 * 
 * Unless you have purchased a commercial license,
 * the following license terms apply:
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.iplass.mtp.impl.entity.cache;

import org.iplass.mtp.entity.query.Query;

class QueryCacheKey {
	final boolean returnStructuredEntity;
	final Query query;
	final boolean countOnly;
	private final int hash;
	
	public QueryCacheKey(Query query, boolean returnStructuredEntity, boolean countOnly) {
		this.query = query;
		this.returnStructuredEntity = returnStructuredEntity;
		this.countOnly = countOnly;
		hash = genHash();
	}

	private int genHash() {
		final int prime = 31;
		int result = 1;
		result = prime * result + (countOnly ? 1231 : 1237);
		result = prime * result + ((query == null) ? 0 : query.hashCode());
		result = prime * result + (returnStructuredEntity ? 1231 : 1237);
		return result;
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		QueryCacheKey other = (QueryCacheKey) obj;
		if (countOnly != other.countOnly)
			return false;
		if (query == null) {
			if (other.query != null)
				return false;
		} else if (!query.equals(other.query))
			return false;
		if (returnStructuredEntity != other.returnStructuredEntity)
			return false;
		return true;
	}
}
